//2011.03.30.L -> Fixed Some Minor Stuff
//2011.03.27.L -> Original Version

#include <stdlib.h>
#include "VGA.h"
#include "Laser_Track.h"

void getRawLaserCoordinates(struct LaserTrackerModule * modulePtr, struct LocalTrackerDataStruct * dataStructPtr) 
{
	/*This function obtains the coordinates of the two laser dots.
		It takes a pointer to the hardware tracker module and a pointer to a local data struct.
		The values of the coordinates are saved inside the struct pointed to by dataStructPtr.
	*/
	
	dataStructPtr->in_buf_L = modulePtr->currentPositions;
	
	dataStructPtr->X_pos_2 = (dataStructPtr->in_buf_L >> 0) & 2047;
	dataStructPtr->Y_pos_2 = (dataStructPtr->in_buf_L >> 12) & 1023;
	dataStructPtr->F_num_2 = (dataStructPtr->in_buf_L >> 22) & 1023;
	
	dataStructPtr->X_pos_1 = (dataStructPtr->in_buf_L >> 32) & 2047;
	dataStructPtr->Y_pos_1 = (dataStructPtr->in_buf_L >> 44) & 1023;
	dataStructPtr->F_num_1 = (dataStructPtr->in_buf_L >> 54) & 1023;
	
	//xil_printf("X_pos_1 = %d; Y_pos_1 = %d; F_num_1 = %d\r\n", dataStructPtr->X_pos_1, dataStructPtr->Y_pos_1, dataStructPtr->F_num_1);
	//xil_printf("X_pos_2 = %d; Y_pos_2 = %d; F_num_2 = %d\r\n\n", dataStructPtr->X_pos_2, dataStructPtr->Y_pos_2, dataStructPtr->F_num_2);
}

void drawSwipeLine(struct Screen* in, unsigned int color, int x1, int y1, int x2, int y2)
{
	/*This function draws out a line between the two points specified by the input parameters.
		"color" specifies the color of the line. Also, a marker is drawn at each end of the line
		(Red for point 1 and Blue for point 2).
	*/
	
	int i, j, incI, incJ;
	double deltaI, deltaJ, secCoord;
	
	deltaI = x2 - x1;
	deltaJ = y2 - y1;
	
	//Drawing Line
	if ( abs(deltaI) > abs(deltaJ) )
	{
		if (deltaI < 0)	incI = -1;
		else	incI = 1;
		for(i = 0; i <= abs(deltaI); i++)
		{
			secCoord = (y1) + (deltaJ/deltaI)*i*incI;
			//xil_printf("secCoord = %d\r\n", (int) secCoord);
			write_pixel(in, color, x1 + incI*i, (int) secCoord);
		}
	}
	else
	{
		if (deltaJ < 0)	incJ = -1;
		else	incJ = 1;
		for(j = 0; j <= abs(deltaJ); j++)
		{
			secCoord = (x1) + (deltaI/deltaJ)*j*incJ;
			//xil_printf("secCoord = %d\r\n", (int) secCoord);
			write_pixel(in, color, (int) secCoord, y1 + incJ*j);
		}
	}
	
	//Drawing Laser1 Marker (Red)
	incI = -3;
	for (j = -3; j <= 3; j++)
	{
		for (i=j+incI; i <= (j+incI)*(-1); i++)
		{
			if ( (x1+i>=0)&&(x1+i<=639)&&(y1+j>=0)&&(y1+j<=479) )
				write_pixel(in, (int) 0xFFF00000, x1+i, y1+j);
		}
	}
	
	//Drawing Laser2 Marker (Blue)
	incI = 3;
	for (j = -3; j <= 3; j++)
	{
		for (i=j+incI; i <= (j+incI)*(-1); i++)
		{
			if ( (x2+i>=0)&&(x2+i<=639)&&(y2+j>=0)&&(y2+j<=479) )
				write_pixel(in, (int) 0x000000FF, x2+i, y2+j);
		}
		incI = incI - 2;
	}
}
