

#ifndef _VGA_H_
#define _VGA_H_
	//Author: Andrew Shorten
	//Date: March 2009
	//Purpose: Provide double buffered c access to the xps-tft module

	//Define the screen resolution
	#define VGA_X_RES 640
	#define VGA_Y_RES 480

	//The struct responsible for representing a single vga screen
	//In a regular setup, two of these structs are used to perform
	//double buffering
	struct Screen
	{
		unsigned int pixel_data[491520];
	};

	//The struct responsible for interfacing with a vga controller module
	//Takes care of double buffering
	struct Buffered_screen
	{
		struct Screen* screen_0;
		struct Screen* screen_1;
		int* control;
		int displayed;
	};

	//Writes the given pixel value to the given screen at the given x-y location
	void write_pixel(struct Screen* in, unsigned int value, unsigned int x, unsigned int y);

	//Writes the given RGB pixel value to the given screen at the given x-y location
	void write_pixel_rgb(struct Screen* in, unsigned int R, unsigned int G, unsigned int B, unsigned int x, unsigned int y);

	//Clears the given screen to the given pixel value
	void cal_screen(struct Screen* in, unsigned int value, unsigned int box_color, int cal_pos);
	//Clears the given screen to the given pixel value
	void clear_screen(struct Screen* in, unsigned int value, unsigned int box_color);

	//Initializes the given Buffered_screen struct with the given screen and xps_tft control pointer information
	//The control pointer points to the first memory location of the xps_tft's PLB slave interface and can be used
	//to switch what place in memory the module is reading from
	void init_buffered_screen(struct Buffered_screen* in, struct Screen* screen_a, struct Screen* screen_b, int* control);

	//Makes the VGA controller swap between the two different vga screens
	void swap(struct Buffered_screen* in);

	//Returns the screen that is not currently beeing displayed
	struct Screen* get_undisplayed(struct Buffered_screen* in);

	//Gets the pixel value at the given x-y location of the given vga screen
	unsigned int get_pixel(struct Screen* in, unsigned int x, unsigned int y);
#endif
