//Laser Track Game Main

//2011.03.30.L -> Fixed Some Minor Stuff
//2011.03.28.L -> Implemented 2 Dot Laser Tracking
//.....................................
//2011.03.01.L -> Initial version of the track tester

#include <xbasic_types.h>
#include <xparameters.h>
#include <xiic_l.h>
#include "VGA.h"
#include "Game.h"
#include "Laser_Track.h"

#define DECODER_ADDR 0x20 //Read: 0x41, Write: 0x40
#define SKIP_CALIB 0
#define BG_COLOUR 0x00FFFFFF
#define BOX_COLOUR 0x77777777

struct VideoModule {
  Xuint8 addr;
  Xuint8 config_val;
  Xuint8 actual_val;
};

//Composite Configuration constants
#define DECODER_COMP_CONFIG_CNT 18
struct VideoModule decoder_comp[] = { 
  { 0x00, 0x04, 0 },
  { 0x15, 0x00, 0 },
  { 0x17, 0x41, 0 },
  { 0x27, 0x58, 0 },
  { 0x3a, 0x16, 0 }, 
  { 0x50, 0x04, 0 },
  { 0x0e, 0x80, 0 },
  { 0x50, 0x20, 0 },
  { 0x52, 0x18, 0 }, 
  { 0x58, 0xed, 0 },
  { 0x77, 0xc5, 0 },
  { 0x7c, 0x93, 0 },
  { 0x7d, 0x00, 0 },
  { 0xd0, 0x48, 0 },
  { 0xd5, 0xa0, 0 },
  { 0xd7, 0xea, 0 },
  { 0xe4, 0x3e, 0 },
  { 0xea, 0x0f, 0 }, 
  { 0x0e, 0x00, 0 } };

void configDecoder(struct VideoModule *decoder, int config_cnt );

int main() 
{
	struct Buffered_screen buf;
	struct Screen * vga1    = (struct Screen *) (0x42000000);
	struct Screen * vga2    = (struct Screen *) (0x43000000);
	struct Screen * temp;
	
	//===== Tracker Variable Instantiations =============
	struct LaserTrackerModule * LM_ptr;
	struct LocalTrackerDataStruct LocalTrackerData;
	struct LocalTrackerDataStruct * LD_ptr;
	//===================================================
	
	int stable = 0;
	int stable_count = 0;
	float old_x;
	float old_y;
	float delta_x;
	float delta_y;
	
	int laser_x;
	int laser_y;
	
	float x1;
	float x2;
	float y1;
	float y2;
	
	print("\r\n\nBeginning Video Decoder Setup\r\n");
	configDecoder(decoder_comp, DECODER_COMP_CONFIG_CNT);
	print("\r\nVideo Decoder Setup Complete!\r\n\r\n");
	
	//Initialze vga output variables
	init_buffered_screen(&buf, vga1, vga2, (int *) 0x85000000);

	//===== Initializing the Tracker =======================
	LM_ptr = (struct LaserTrackerModule *) LASER_TRACK_BASE_ADDR;
	LD_ptr = &LocalTrackerData;
	LD_ptr->out_buf_I = (int) RED_LASER_COLOR;
	LM_ptr->colorLimits = LD_ptr->out_buf_I;
	LD_ptr->in_buf_I = LM_ptr->colorLimits;
	xil_printf("Mem Contents at %02x = %02x\r\n", LM_ptr, LD_ptr->in_buf_I);
	//======================================================

	temp = get_undisplayed(&buf);
	cal_screen(temp, BG_COLOUR, BOX_COLOUR, 1);	
	swap(&buf);

	if(!SKIP_CALIB) {
		//Get top left
		stable = 0;	
		stable_count = 0;	
		getRawLaserCoordinates(LM_ptr, LD_ptr); //Getting the Coordinates
		while (stable_count < 1000) {
			if (LD_ptr->X_pos_1 ==0 && LD_ptr->Y_pos_1 ==0) {
				stable_count++;
			} else {
				stable_count = 0;
			}
			getRawLaserCoordinates(LM_ptr, LD_ptr); //Getting the Coordinates
		}
		stable_count = 0;
		xil_printf("Ready to begin calibration\n");
		while (stable == 0) {
			getRawLaserCoordinates(LM_ptr, LD_ptr); //Getting the Coordinates
			if (LD_ptr->X_pos_1 !=0 && LD_ptr->Y_pos_1 !=0 && LD_ptr->X_pos_1 < 150 && LD_ptr->Y_pos_1 < 150) {
				if (LD_ptr->X_pos_1 <= old_x + 5 && LD_ptr->X_pos_1 >= old_x -5 && LD_ptr->Y_pos_1 <= old_y + 5 && LD_ptr->Y_pos_1 >= old_y -5)
					stable_count++;
				else
					stable_count = 0;
			}else {
				stable_count = 0;
			}
			old_x = LD_ptr->X_pos_1;	
			old_y = LD_ptr->Y_pos_1;

			if (stable_count == 1000)
				stable = 1;
		}
		delta_x = LD_ptr->X_pos_1 - 50;
		delta_y = LD_ptr->Y_pos_1 - 50;
		x1 = LD_ptr->X_pos_1;
		y1 = LD_ptr->Y_pos_1;
		xil_printf("Stable top-left is: X_pos = %d; Y_pos = %d; \r\n",(int)x1, (int)y1);
		cal_screen(temp, BG_COLOUR, BOX_COLOUR, 2);	
		//swap(&buf);
		
		//Get bottom right
		stable = 0;	
		stable_count = 0;	
		while (stable == 0) {
			getRawLaserCoordinates(LM_ptr, LD_ptr); //Getting the Coordinates
			if (LD_ptr->X_pos_1 !=0 && LD_ptr->Y_pos_1 !=0 && LD_ptr->X_pos_1 > 300 && LD_ptr->Y_pos_1 > 200) {
				if (LD_ptr->X_pos_1 <= old_x + 5 && LD_ptr->X_pos_1 >= old_x -5 && LD_ptr->Y_pos_1 <= old_y + 5 && LD_ptr->Y_pos_1 >= old_y -5)
					stable_count++;
				else
					stable_count = 0;
			}else {
				stable_count = 0;
			}
			old_x = LD_ptr->X_pos_1;	
			old_y = LD_ptr->Y_pos_1;

			if (stable_count == 1000)
				stable = 1;
		}
		x2 = LD_ptr->X_pos_1;
		y2 = LD_ptr->Y_pos_1;
		xil_printf("Stable bottom-right is: X_pos = %d; Y_pos = %d; \r\n", (int)x2, (int)y2);
	}

	Game(x1, y1, x2, y2, &buf, LM_ptr, LD_ptr);
	
	return 1; //Should never get here
} 

void configDecoder(struct VideoModule *decoder, int config_cnt ) 
{
  Xuint16 send_cnt, i;
  Xuint8 send_data[2] = {0};
  Xuint8 success = 1;
  send_cnt = 2;
  xil_printf("  Configuring Decoder...\t");
  //read in configuration constants and send them to the VDEC one by one
  for( i = 0; i < config_cnt; i++ )
   {

    send_data[0] = decoder[i].addr;

    send_data[1] = decoder[i].config_val;

    send_cnt = XIic_Send(XPAR_IIC_BASEADDR, DECODER_ADDR, send_data, 2,XIIC_STOP );

    if( send_cnt != 2 ) 
	 {
      xil_printf("Error writing to address %02x\r\n", decoder[i].addr);
      success = 0;
      break;
     }
   }

  if( success )
    xil_printf("SUCCESS!\r\n");
}
