/* $Id: xtft_hw.h,v 1.1.2.2 2008/06/16 08:49:16 suneelg Exp $ */
/****************************************************************************
*
*	XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"
*	AS A COURTESY TO YOU, SOLELY FOR USE IN DEVELOPING PROGRAMS AND
*	SOLUTIONS FOR XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE,
*	OR INFORMATION AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE,
*	APPLICATION OR STANDARD, XILINX IS MAKING NO REPRESENTATION
*	THAT THIS IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,
*	AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE
*	FOR YOUR IMPLEMENTATION. XILINX EXPRESSLY DISCLAIMS ANY
*	WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE
*	IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR
*	REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF
*	INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
*	FOR A PARTICULAR PURPOSE.
*
*	(c) Copyright 2008 Xilinx Inc.
*	All rights reserved.
*
****************************************************************************/
/***************************************************************************/
/**
*
* @file xtft_hw.h
*
* This file defines the macros and definitions for the Xilinx TFT Controller
* device.
*
* <pre>
* MODIFICATION HISTORY:
*
* Ver    Who   Date      Changes
* -----  ----  --------  -----------------------------------------------
* 1.00a  sg    03/24/08  First release
* </pre>
*
****************************************************************************/
#ifndef XTFT_HW_H  /* prevent circular inclusions */
#define XTFT_HW_H  /* by using protection macros  */

#ifdef __cplusplus
extern "C" {
#endif

/***************************** Include Files *******************************/
#include "xbasic_types.h"
#include "xio.h"
#ifdef __PPC__
#include "xio_dcr.h"
#endif

/************************** Constant Definitions ***************************/

/**
 * @name TFT Register offsets
 *
 * The following definitions provide access to each of the registers of the
 * TFT device. These are defined for access through a PLB Bus. They need to be
 * divided by 4 for access through the DCR Bus.
 * @{
 */
#define XTFT_AR_OFFSET		0 /**< Address Reg (Video memory) Offset */
#define XTFT_CR_OFFSET		4 /**< Control Register Offset */

/*@}*/

/**
 * @name TFT Control Register (CR) mask(s)
 * @{
 */
#define XTFT_CR_TDE_MASK	0x01 /**< TFT Display Enable Bit Mask */
#define XTFT_CR_DPS_MASK	0x02 /**< TFT Display Scan Control Bit Mask */
/*@}*/

/**
 * Dimension Definitions
 */
#define XTFT_CHAR_WIDTH			8    /**< Character width */
#define XTFT_CHAR_HEIGHT		12   /**< Character height */
#define XTFT_DISPLAY_WIDTH		640  /**< Width of the screen */
#define XTFT_DISPLAY_HEIGHT		480  /**< Height of the screen */
#define XTFT_DISPLAY_BUFFER_WIDTH	1024 /**< Buffer width of a line */


/*
 * This shift is used for accessing the TFT registers through DCR bus.
 */
#define XTFT_DCR_REG_SHIFT		2    /**< Reg Shift for DCR Access */

/**************************** Type Definitions *****************************/

/***************** Macros (Inline Functions) Definitions *******************/

/***************************************************************************/
/**
*
* To fill a particular pixel with the given 32bit color value.
*
* @param	VideoMemBaseAddr is the video memory base address.
* @param	ColVal represents the column on the screen. The valid values
*		are 0 to (XTFT_DISPLAY_WIDTH - 1).
* @param	RowVal represents the row on the screen. The valid values
*		are 0 to (XTFT_DISPLAY_HEIGHT - 1).
* @param	PixelVal represents the color with which it will be
*		filled on screen.
*
* @return	None.
*
* @note		This macro is independent of the interface the TFT
*		Controller is connected to.
*		C-style signature:
*		void XTft_mSetPixel(u32 VideoMemBaseAddr, u32 ColVal,
*			u32 RowVal, u32 PixelVal).
*
****************************************************************************/
#define XTft_mSetPixel(VideoMemBaseAddr, ColVal, RowVal, PixelVal) \
	XIo_Out32((VideoMemBaseAddr) + \
	4 * ((RowVal) * XTFT_DISPLAY_BUFFER_WIDTH + ColVal), PixelVal)

/***************************************************************************/
/**
*
* To obtain the color value at the given row and column position.
*
* @param	VideoMemBaseAddr is the video memory base address.
* @param	ColVal represents the column on the screen. The valid values
*		are 0 to (XTFT_DISPLAY_WIDTH - 1).
* @param	RowVal represents the row on the screen. The valid values
*		are 0 to (XTFT_DISPLAY_HEIGHT - 1).
*
* @return	A 32 bit color value from the given column and row position.
*
* @note		This macro is independent of the interface the TFT
*		Controller is connected to.
*		C-style signature:
*		u32 XTft_mGetPixel(u32 VideoMemBaseAddr, u32 ColVal,
*					u32 RowVal)
*
****************************************************************************/
#define XTft_mGetPixel(VideoMemBaseAddr, ColVal, RowVal) \
	XIo_In32((VideoMemBaseAddr) + 4 * \
	((RowVal) * XTFT_DISPLAY_BUFFER_WIDTH + ColVal))

/************************** Function Prototypes ****************************/

/************************** Variable Definitions ***************************/

/************************** Function Definitions ****************************/

#ifdef __cplusplus
}
#endif

#endif /* XTFT_HW_H */
